( cd usr/bin ; rm -rf corepack )
( cd usr/bin ; ln -sf ../lib64/node_modules/corepack/dist/corepack.js corepack )
( cd usr/bin ; rm -rf npm )
( cd usr/bin ; ln -sf ../lib64/node_modules/npm/bin/npm-cli.js npm )
( cd usr/bin ; rm -rf npx )
( cd usr/bin ; ln -sf ../lib64/node_modules/npm/bin/npx-cli.js npx )
